Version 0.0.3
-------------

  * Add parcellation derived from Harvard-Oxford template, to be
    used with the nonlinear-asym-09c template for the carpetplot
  * Add headmask and normalize tpms in mni_icbm152_nlin_asym_09c
  * Update MNI ICBM152 templates (linear and nonlinear-asym)
  * Add MNI152 2009c nonlinear-symetric template (LAS)
  * Add MNI152 nonlinear-symmetric template
  * Add MNI EPI template and parcellation
  * Switch data downloads from GDrive to OSF
  * Fixed installer, now compatible with python 3

Version 0.0.2
-------------

  * Added MRI reorient workflow (based on AFNI)


Version 0.0.1
-------------

  * Added skull-stripping workflow based on AFNI
  * Rewritten most of the shablona-derived names and description files
  * Copied project structure from Shablona